@@ -1,6 +1,36 @@
 import argparse
 import inspect
 import re
+
+def bindSignatureArgs(func, src:dict) -> dict:
+    '''
+
+    Args:
+        func: Function/method from which the signature will be sourced.
+        src: Source dictionary that will provide values for dest.
+
+    Returns:
+        A new dictionary with argument values from src set
+        in dest.
+
+    '''
+
+    dest = {}
+
+    # Iterate over paramaters and values in the function's
+    # signature
+    for k,v in inspect.signature(func).parameters.items():
+
+        # Skip "self" references
+        if k == 'self': continue
+
+        # Extract the user supplied value when provided
+        if k in src: dest[k]=src[k]
+
+        # Use the default value other wise
+        else: dest[k]=v
+
+    return dest
         
 class Module:
 
@@ -58,22 +88,19 @@ class Module:
 
         # Initialize a dictionary to hold all of the necessary argument
         # to initialize the brute force module.
-        dct = {}
-
-        # Take each argparse value and add it to the dictionary
-        for k,v in inspect.signature(cls.__init__).parameters.items():
-
-            # Skip "self" references
-            if k == 'self': continue
-
-            # Extract the user supplied value when provided
-            if k in args: dct[k]=args[k]
-
-            # Use the default value other wise
-            else: dct[k]=v
+        dct = bindSignatureArgs(func=cls.__init__, src=args)
 
         # Initialize and return the module
-        return cls(**dct)
+        instance = cls(**dct)
+
+        if hasattr(instance, '__post_init__'):
+
+            instance.__post_init__(
+                **bindSignatureArgs(
+                    func=instance.__post_init__,
+                    src=args))
+
+        return instance
 
     @classmethod
     def validate(cls):
@@ -107,6 +134,7 @@ class Module:
     def get_handle(cls):
         '''Return a simple string to use as a module identifier.
         '''
+
         return '.'.join(cls.__module__.split('.')[-3:][:2])
 
     @classmethod
@@ -117,18 +145,14 @@ class Module:
         declared in __init__ and build an interface via argparse.
         '''
 
-        # =====================
-        # INITIALIZE THE PARSER
-        # =====================
-        '''Here we create a new argparse argument parser for the command
-        assoicated with the newly created module. This is how we bind
-        the name that the user will refernce at the commandline, along
-        with providing a mechanism to assign values to module parameters.
-        '''
-
         epilog = None
         if hasattr(cls, 'contributors'):
-            epilog = 'Module Contributors:\n\n'
+
+            # ==========================
+            # FORMAT MODULE CONTRIBUTORS
+            # ==========================
+
+            epilog = 'Contributors:\n\n'
 
             if not isinstance(cls.contributors, list):
 
@@ -152,7 +176,7 @@ class Module:
                     raise ValueError(
                         'contributor records must have a "name" field')
 
-                epilog += f'- {name}'
+                epilog += f'\n- {name}'
 
                 if additional:
 
@@ -166,6 +190,37 @@ class Module:
 
                         epilog += f'\n  {k}: {v}'
 
+
+                epilog += '\n'
+
+        if hasattr(cls, 'references'):
+
+            # ========================
+            # FORMAT MODULE REFERENCES
+            # ========================
+
+            epilog += f'\nReferences:\n'
+
+            references = cls.references
+
+            if not isinstance(references, list):
+
+                raise ValueError(
+                    f'References must be a list, got {type(references)}')
+
+            for ref in references:
+                epilog += f'\n- {ref}'
+
+        # ======================
+        # BUILD MODULE ARGUMENTS
+        # ======================
+
+        '''Here we create a new argparse argument parser for the command
+        assoicated with the newly created module. This is how we bind
+        the name that the user will refernce at the commandline, along
+        with providing a mechanism to assign values to module parameters.
+        '''
+
         parser = subparsers.add_parser(cls.get_handle(),
                 description=cls.description,
                 help=cls.brief_description,
